// Copyright (c) 2023 Tudor Stanciu

import { Dispatch } from "react";
import { acquire } from "@flare/tuitio-client";
import { initialState } from "./initialState";
import type { TuitioReactState, TuitioDispatchActions } from "./types";

export const reducer = (state: TuitioReactState = initialState, action: any): TuitioReactState => {
  switch (action.type) {
    case "onLoginSuccess": {
      const { token, validUntil, userName } = action;
      return {
        ...state,
        auth: {
          token,
          validUntil,
          userName
        }
      };
    }
    case "onLogoutSuccess": {
      return {
        ...state,
        auth: { ...acquire() },
        userInfo: undefined
      };
    }
    case "onUserInfoLoaded": {
      const { userInfo } = action;
      return {
        ...state,
        userInfo
      };
    }
    default: {
      return state;
    }
  }
};

export const dispatchActions = (dispatch: Dispatch<any>): TuitioDispatchActions => ({
  onLoginSuccess: (token: string, validUntil: Date, userName: string): void =>
    dispatch({ type: "onLoginSuccess", token, validUntil, userName }),
  onLogoutSuccess: (): void => dispatch({ type: "onLogoutSuccess" }),
  onUserInfoLoaded: (userInfo): void => dispatch({ type: "onUserInfoLoaded", userInfo })
});
